@@ -29,6 +29,7 @@ class DataFileSelectorSchema(Schema):
 
     area = fields.Decimal(allow_none=True)
     length = fields.Decimal(allow_none=True)
+    points = fields.Integer(allow_none=True)
 
     initial_values = fields.List(fields.String(required=True), allow_none=True)
     minimum = fields.Decimal(allow_none=True)
@@ -75,9 +76,7 @@ class DataFileSchema(Schema):
     bounds = fields.List(fields.Decimal(required=True), allow_none=True, metadata={'read_only': True})  # Changed to prevent this being updated.
     area = fields.Decimal(allow_none=True, metadata={'read_only': True})  # Changed to prevent this being updated.
     length = fields.Decimal(allow_none=True, metadata={'read_only': True})  # Changed to prevent this being updated.
-    mgrs_cells = fields.List(fields.String(required=True), allow_none=True, metadata={'read_only': True})  # Changed to prevent this being updated.
-    sinusoidal_cells = fields.List(fields.Tuple((fields.Integer, fields.Integer), required=True), allow_none=True,
-                                   metadata={'read_only': True})  # Changed to prevent this being updated.
+    points = fields.Integer(allow_none=True, metadata={'read_only': True})  # Changed to prevent this being updated.
 
     size = fields.Integer(allow_none=True, metadata={'read_only': True})  # Changed to prevent this being updated.
     error = fields.Boolean(allow_none=True, metadata={'read_only': True})  # Changed to prevent this being updated.
